@@ -182,7 +182,7 @@ $database = array(
 			"dell_lifecycle_version" => "varchar(32) NOT NULL default ''",
 			"ipmi_firmware_version" => "varchar(32) NOT NULL default ''",
 			"ipmi_detected_ip" => "varchar(64) NOT NULL default ''",
-			"use_ceph_if_available" => "enum('yes','no') NOT NULL default 'no'",
+			"use_ceph_if_available" => "enum('yes','no') NOT NULL default 'yes'",
 			"dest_blk" => "varchar(32) NOT NULL default 'none'",
 			"install_on_raid" => "enum('yes','no') NOT NULL default 'no'",
 			"raid_type" => "enum('0','1','10','5') NOT NULL default '1'",
